@@ -27,6 +27,7 @@ Tailbone Web API - Batch Views
 from __future__ import unicode_literals, absolute_import
 
 import logging
+import warnings
 
 import six
 
@@ -84,7 +85,14 @@ class APIBatchView(APIBatchMixin, APIMasterView):
 
     def __init__(self, request, **kwargs):
         super(APIBatchView, self).__init__(request, **kwargs)
-        self.handler = self.get_handler()
+        self.batch_handler = self.get_handler()
+
+    @property
+    def handler(self):
+        warnings.warn("the `handler` property is deprecated; "
+                      "please use `batch_handler` instead",
+                      DeprecationWarning, stacklevel=2)
+        return self.batch_handler
 
     def normalize(self, batch):
         app = self.get_rattail_app()
@@ -115,7 +123,7 @@ class APIBatchView(APIBatchMixin, APIMasterView):
             'executed_display': self.pretty_datetime(executed) if executed else None,
             'executed_by_uuid': batch.executed_by_uuid,
             'executed_by_display': six.text_type(batch.executed_by or ''),
-            'mutable': self.handler.is_mutable(batch),
+            'mutable': self.batch_handler.is_mutable(batch),
         }
 
     def create_object(self, data):
@@ -128,9 +136,9 @@ class APIBatchView(APIBatchMixin, APIMasterView):
         user = self.request.user
         kwargs = dict(data)
         kwargs['user'] = user
-        batch = self.handler.make_batch(self.Session(), **kwargs)
-        if self.handler.should_populate(batch):
-            self.handler.do_populate(batch, user)
+        batch = self.batch_handler.make_batch(self.Session(), **kwargs)
+        if self.batch_handler.should_populate(batch):
+            self.batch_handler.do_populate(batch, user)
         return batch
 
     def update_object(self, batch, data):
@@ -198,7 +206,7 @@ class APIBatchView(APIBatchMixin, APIMasterView):
         kwargs = dict(self.request.json_body)
         kwargs.pop('user', None)
         kwargs.pop('progress', None)
-        result = self.handler.do_execute(batch, self.request.user, **kwargs)
+        result = self.batch_handler.do_execute(batch, self.request.user, **kwargs)
         return {'ok': bool(result), 'batch': self.normalize(batch)}
 
     @classmethod
@@ -252,7 +260,14 @@ class APIBatchRowView(APIBatchMixin, APIMasterView):
 
     def __init__(self, request, **kwargs):
         super(APIBatchRowView, self).__init__(request, **kwargs)
-        self.handler = self.get_handler()
+        self.batch_handler = self.get_handler()
+
+    @property
+    def handler(self):
+        warnings.warn("the `handler` property is deprecated; "
+                      "please use `batch_handler` instead",
+                      DeprecationWarning, stacklevel=2)
+        return self.batch_handler
 
     def normalize(self, row):
         batch = row.batch
@@ -267,7 +282,7 @@ class APIBatchRowView(APIBatchMixin, APIMasterView):
             'batch_description': batch.description,
             'batch_complete': batch.complete,
             'batch_executed': bool(batch.executed),
-            'batch_mutable': self.handler.is_mutable(batch),
+            'batch_mutable': self.batch_handler.is_mutable(batch),
             'sequence': row.sequence,
             'status_code': row.status_code,
             'status_display': row.STATUS.get(row.status_code, six.text_type(row.status_code)),
@@ -280,14 +295,14 @@ class APIBatchRowView(APIBatchMixin, APIMasterView):
         Invokes the batch handler's ``refresh_row()`` method after updating the
         row's field data per usual.
         """
-        if not self.handler.is_mutable(row.batch):
+        if not self.batch_handler.is_mutable(row.batch):
             return {'error': "Batch is not mutable"}
 
         # update row per usual
         row = super(APIBatchRowView, self).update_object(row, data)
 
         # okay now we apply handler refresh logic
-        self.handler.refresh_row(row)
+        self.batch_handler.refresh_row(row)
         return row
 
     def delete_object(self, row):
@@ -296,7 +311,7 @@ class APIBatchRowView(APIBatchMixin, APIMasterView):
 
         Delegates deletion of the row to the batch handler.
         """
-        self.handler.do_remove_row(row)
+        self.batch_handler.do_remove_row(row)
 
     def quick_entry(self):
         """
@@ -312,10 +327,10 @@ class APIBatchRowView(APIBatchMixin, APIMasterView):
         entry = data['quick_entry']
 
         try:
-            row = self.handler.quick_entry(self.Session(), batch, entry)
+            row = self.batch_handler.quick_entry(self.Session(), batch, entry)
         except Exception as error:
             log.warning("quick entry failed for '%s' batch %s: %s",
-                        self.handler.batch_key, batch.id_str, entry,
+                        self.batch_handler.batch_key, batch.id_str, entry,
                         exc_info=True)
             msg = six.text_type(error)
             if not msg and isinstance(error, NotImplementedError):
