@@ -26,6 +26,8 @@ Rattail config extension for Tailbone
 
 from __future__ import unicode_literals, absolute_import
 
+from pkg_resources import parse_version
+
 from rattail.config import ConfigExtension as BaseExtension
 from rattail.db.config import configure_session
 
@@ -61,6 +63,18 @@ def csrf_header_name(config):
     return config.get('tailbone', 'csrf_header_name', default='X-CSRF-TOKEN')
 
 
+def get_buefy_version(config):
+    return config.get('tailbone', 'buefy_version') or '0.8.17'
+
+
+def get_buefy_0_8(config, version=None):
+    if not version:
+        version = get_buefy_version(config)
+    if version == 'latest':
+        return False
+    return parse_version(version) < parse_version('0.9')
+
+
 def global_help_url(config):
     return config.get('tailbone', 'global_help_url')
 
