@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -58,4 +58,7 @@ class Feedback(colander.Schema):
     user_name = colander.SchemaNode(colander.String(),
                                     missing=colander.null)
 
+    please_reply_to = colander.SchemaNode(colander.String(),
+                                          missing=colander.null)
+
     message = colander.SchemaNode(colander.String())
