@@ -48,7 +48,8 @@ from pyramid_deform import SessionFileUploadTempStore
 from pyramid.renderers import render
 from webhelpers2.html import tags, HTML
 
-from tailbone.util import raw_datetime, get_form_data
+from tailbone.db import Session
+from tailbone.util import raw_datetime, get_form_data, render_markdown
 from . import types
 from .widgets import ReadonlyWidget, PlainDateWidget, JQueryDateWidget, JQueryTimeWidget
 from tailbone.exceptions import TailboneJSONFieldError
@@ -337,6 +338,8 @@ class Form(object):
                  hidden={}, widgets={}, defaults={}, validators={}, required={}, helptext={}, focus_spec=None,
                  action_url=None, cancel_url=None, use_buefy=None, component='tailbone-form',
                  vuejs_field_converters={},
+                 # TODO: ugh this is getting out hand!
+                 can_edit_help=False, edit_help_url=None, route_prefix=None,
     ):
         self.fields = None
         if fields is not None:
@@ -375,6 +378,9 @@ class Form(object):
         self.use_buefy = use_buefy
         self.component = component
         self.vuejs_field_converters = vuejs_field_converters or {}
+        self.can_edit_help = can_edit_help
+        self.edit_help_url = edit_help_url
+        self.route_prefix = route_prefix
 
     def __iter__(self):
         return iter(self.fields)
@@ -800,6 +806,11 @@ class Form(object):
         context = kwargs
         context['form'] = self
         context['dform'] = dform
+        context.setdefault('can_edit_help', self.can_edit_help)
+        if context['can_edit_help']:
+            context.setdefault('edit_help_url', self.edit_help_url)
+            context['field_labels'] = self.get_field_labels()
+            context['field_markdowns'] = self.get_field_markdowns()
         context.setdefault('form_kwargs', {})
         # TODO: deprecate / remove the latter option here
         if self.auto_disable_save or self.auto_disable:
@@ -815,6 +826,22 @@ class Form(object):
         context['render_field_readonly'] = self.render_field_readonly
         return render(template, context)
 
+    def get_field_labels(self):
+        return dict([(field, self.get_label(field))
+                     for field in self])
+
+    def get_field_markdowns(self):
+        model = self.request.rattail_config.get_model()
+
+        if not hasattr(self, 'field_markdowns'):
+            infos = Session.query(model.TailboneFieldInfo)\
+                           .filter(model.TailboneFieldInfo.route_prefix == self.route_prefix)\
+                           .all()
+            self.field_markdowns = dict([(info.field_name, info.markdown_text)
+                                         for info in infos])
+
+        return self.field_markdowns
+
     def get_vuejs_model_value(self, field):
         """
         This method must return "raw" JS which will be assigned as the initial
@@ -873,26 +900,35 @@ class Form(object):
         not for "readonly" fields.
         """
         dform = self.make_deform_form()
-        field = dform[fieldname]
+        field = dform[fieldname] if fieldname in dform else None
+
+        include = bool(field)
+        if self.readonly or (not field and fieldname in self.readonly_fields):
+            include = True
+        if not include:
+            return
 
         if self.field_visible(fieldname):
+            label = self.get_label(fieldname)
+            markdowns = self.get_field_markdowns()
 
             # these attrs will be for the <b-field> (*not* the widget)
             attrs = {
                 ':horizontal': 'true',
-                'label': self.get_label(fieldname),
             }
 
             # add some magic for file input fields
-            if isinstance(field.schema.typ, deform.FileData):
+            if field and isinstance(field.schema.typ, deform.FileData):
                 attrs['class_'] = 'file'
 
             # show helptext if present
+            # TODO: older logic did this only if field was *not*
+            # readonly, perhaps should add that back..
             if self.has_helptext(fieldname):
                 attrs['message'] = self.render_helptext(fieldname)
 
             # show errors if present
-            error_messages = self.get_error_messages(field)
+            error_messages = self.get_error_messages(field) if field else None
             if error_messages:
 
                 # TODO: this surely can't be what we ought to do
@@ -913,15 +949,58 @@ class Form(object):
             attrs.update(bfield_attrs)
 
             # render the field widget or whatever
-            html = field.serialize(use_buefy=True,
-                                   **self.get_renderer_kwargs(fieldname))
-            # TODO: why do we not get HTML literal from serialize() ?
-            html = HTML.literal(html)
+            if self.readonly or fieldname in self.readonly_fields:
+                html = self.render_field_value(fieldname) or HTML.tag('span')
+            elif field:
+                html = field.serialize(use_buefy=True,
+                                       **self.get_renderer_kwargs(fieldname))
+                html = HTML.literal(html)
+
+            # may need a complex label
+            label_contents = [label]
+
+            # add 'help' icon/tooltip if defined
+            if markdowns.get(fieldname):
+                icon = HTML.tag('b-icon', size='is-small', pack='fas',
+                                icon='question-circle')
+                tooltip = render_markdown(markdowns[fieldname])
+
+                # nb. must apply hack to get <template #content> as final result
+                tooltip_template = HTML.tag('template', c=[tooltip],
+                                            **{'#content': 1})
+                tooltip_template = tooltip_template.replace(
+                    HTML.literal('<template #content="1"'),
+                    HTML.literal('<template #content'))
+
+                tooltip = HTML.tag('b-tooltip',
+                                   type='is-white',
+                                   size='is-large',
+                                   multilined='multilined',
+                                   c=[icon, tooltip_template])
+                label_contents.append(HTML.literal('&nbsp; &nbsp;'))
+                label_contents.append(tooltip)
+
+            # add 'configure' icon if allowed
+            if self.can_edit_help:
+                icon = HTML.tag('b-icon', size='is-small', pack='fas',
+                                icon='cog')
+                icon = HTML.tag('a', title="Configure field", c=[icon],
+                                **{'@click.prevent': "configureFieldInit('{}')".format(fieldname),
+                                   'v-show': 'configureFieldsHelp'})
+                label_contents.append(HTML.literal('&nbsp; &nbsp;'))
+                label_contents.append(icon)
+
+            # nb. must apply hack to get <template #label> as final result
+            label_template = HTML.tag('template', c=label_contents,
+                                      **{'#label': 1})
+            label_template = label_template.replace(
+                HTML.literal('<template #label="1"'),
+                HTML.literal('<template #label'))
 
             # and finally wrap it all in a <b-field>
-            return HTML.tag('b-field', c=[html], **attrs)
+            return HTML.tag('b-field', c=[label_template, html], **attrs)
 
-        else: # hidden field
+        elif field: # hidden field
 
             # can just do normal thing for these
             # TODO: again, why does serialize() not return literal?
@@ -1056,6 +1135,8 @@ class Form(object):
         if record:
             try:
                 return record[field_name]
+            except KeyError:
+                return None
             except TypeError:
                 return getattr(record, field_name, None)
 
