@@ -69,6 +69,74 @@ class Grid(object):
     """
     Core grid class.  In sore need of documentation.
 
+    .. _Buefy docs: https://buefy.org/documentation/table/
+
+    .. attribute:: checkable
+
+       Optional callback to determine if a given row is checkable,
+       i.e. this allows hiding checkbox for certain rows if needed.
+
+       This may be either a Python callable, or string representing a
+       JS callable.  If the latter, according to the `Buefy docs`_:
+
+       .. code-block:: none
+
+          Custom method to verify if a row is checkable, works when is
+          checkable.
+
+          Function (row: Object)
+
+       In other words this JS callback would be invoked for each data
+       row in the client-side grid.
+
+       But if a Python callable is used, then it will be invoked for
+       each row object in the server-side grid.  For instance::
+
+          def checkable(obj):
+              if obj.some_property == True:
+                  return True
+              return False
+
+          grid.checkable = checkable
+
+    .. attribute:: check_handler
+
+       Optional JS callback for the ``@check`` event of the underlying
+       Buefy table component.  See the `Buefy docs`_ for more info,
+       but for convenience they say this (as of writing):
+
+       .. code-block:: none
+
+          Triggers when the checkbox in a row is clicked and/or when
+          the header checkbox is clicked
+
+       For instance, you might set ``grid.check_handler =
+       'rowChecked'`` and then define the handler within your template
+       (e.g. ``/widgets/index.mako``) like so:
+
+       .. code-block:: none
+
+          <%def name="modify_this_page_vars()">
+            ${parent.modify_this_page_vars()}
+            <script type="text/javascript">
+
+              TailboneGrid.methods.rowChecked = function(checkedList, row) {
+                  if (!row) {
+                      console.log("no row, so header checkbox was clicked")
+                  } else {
+                      console.log(row)
+                      if (checkedList.includes(row)) {
+                          console.log("clicking row checkbox ON")
+                      } else {
+                          console.log("clicking row checkbox OFF")
+                      }
+                  }
+                  console.log(checkedList)
+              }
+
+            </script>
+          </%def>
+
     .. attribute:: raw_renderers
 
        Dict of "raw" field renderers.  See also
@@ -117,9 +185,11 @@ class Grid(object):
                  sortable=False, sorters={}, default_sortkey=None, default_sortdir='asc',
                  pageable=False, default_pagesize=None, default_page=1,
                  checkboxes=False, checked=None, check_handler=None, check_all_handler=None,
+                 checkable=None,
                  clicking_row_checks_box=False, click_handlers=None,
                  main_actions=[], more_actions=[], delete_speedbump=False,
                  ajax_data_url=None, component='tailbone-grid',
+                 expose_direct_link=False,
                  **kwargs):
 
         self.key = key
@@ -175,6 +245,7 @@ class Grid(object):
             self.checked = lambda item: False
         self.check_handler = check_handler
         self.check_all_handler = check_all_handler
+        self.checkable = checkable
         self.clicking_row_checks_box = clicking_row_checks_box
 
         self.click_handlers = click_handlers or {}
@@ -186,11 +257,12 @@ class Grid(object):
         if ajax_data_url:
             self.ajax_data_url = ajax_data_url
         elif self.request:
-            self.ajax_data_url = self.request.current_route_url()
+            self.ajax_data_url = self.request.current_route_url(_query=None)
         else:
             self.ajax_data_url = ''
 
         self.component = component
+        self.expose_direct_link = expose_direct_link
         self._whgrid_kwargs = kwargs
 
     @property
@@ -1365,6 +1437,7 @@ class Grid(object):
             count = len(raw_data)
 
         # iterate over data rows
+        checkable = self.checkboxes and self.checkable and callable(self.checkable)
         for i in range(count):
             rowobj = raw_data[i]
 
@@ -1372,6 +1445,11 @@ class Grid(object):
             # logic finds it useful
             row = {'_index': i}
 
+            # if grid allows checkboxes, and we have logic to see if
+            # any given row is checkable, add data for that here
+            if checkable:
+                row['_checkable'] = self.checkable(rowobj)
+
             # sometimes we need to include some "raw" data columns in our
             # result set, even though the column is not displayed as part of
             # the grid.  this can be used for front-end editing of row data for
