@@ -40,9 +40,10 @@ from webhelpers2.html import tags
 import tailbone
 from tailbone import helpers
 from tailbone.db import Session
-from tailbone.config import csrf_header_name, should_expose_websockets
+from tailbone.config import (csrf_header_name, should_expose_websockets,
+                             get_buefy_version, get_buefy_0_8)
 from tailbone.menus import make_simple_menus
-from tailbone.util import should_use_buefy
+from tailbone.util import should_use_buefy, get_global_search_options
 
 
 def new_request(event):
@@ -164,8 +165,10 @@ def before_render(event):
             # perhaps too much so, but at least they should work fine.
             renderer_globals['vue_version'] = request.rattail_config.get(
                 'tailbone', 'vue_version') or '2.6.10'
-            renderer_globals['buefy_version'] = request.rattail_config.get(
-                'tailbone', 'buefy_version') or '0.8.13'
+            version = get_buefy_version(rattail_config)
+            renderer_globals['buefy_version'] = version
+            renderer_globals['buefy_0_8'] = get_buefy_0_8(rattail_config,
+                                                          version=version)
 
             # maybe set custom stylesheet
             css = None
@@ -176,6 +179,9 @@ def before_render(event):
                 css = request.rattail_config.get('tailbone', 'theme.falafel.buefy_css')
             renderer_globals['buefy_css'] = css
 
+            # add global search data for quick access
+            renderer_globals['global_search_data'] = get_global_search_options(request)
+
         # here we globally declare widths for grid filter pseudo-columns
         widths = request.rattail_config.get('tailbone', 'grids.filters.column_widths')
         if widths:
