@@ -33,6 +33,8 @@ import pytz
 import humanize
 import logging
 
+import markdown
+
 from rattail.time import timezone, make_utc
 from rattail.files import resource_path
 
@@ -79,6 +81,23 @@ def get_form_data(request):
     return request.POST
 
 
+def get_global_search_options(request):
+    """
+    Returns global search options for current request.  Basically a
+    list of all "index views" minus the ones they aren't allowed to
+    access.
+    """
+    options = []
+    pages = sorted(request.registry.settings['tailbone_index_pages'],
+                   key=lambda page: page['label'])
+    for page in pages:
+        if not page['permission'] or request.has_perm(page['permission']):
+            option = dict(page)
+            option['url'] = request.route_url(page['route'])
+            options.append(option)
+    return options
+
+
 def should_use_buefy(request):
     """
     Returns a flag indicating whether or not the current theme supports (and
@@ -181,6 +200,18 @@ def raw_datetime(config, value, verbose=False, as_date=False):
     return HTML.tag('span', **kwargs)
 
 
+def render_markdown(text, raw=False, **kwargs):
+    """
+    Render the given markdown text as HTML.
+    """
+    kwargs.setdefault('extensions', ['fenced_code', 'codehilite'])
+    md = markdown.markdown(text, **kwargs)
+    if raw:
+        return md
+    md = HTML.literal(md)
+    return HTML.tag('div', class_='rendered-markdown', c=[md])
+
+
 def set_app_theme(request, theme, session=None):
     """
     Set the app theme.  This modifies the *global* Mako template lookup
