@@ -239,5 +239,12 @@ class AuthenticationView(View):
         config.add_view(cls, attr='stop_root', route_name='stop_root')
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    AuthenticationView = kwargs.get('AuthenticationView', base['AuthenticationView'])
     AuthenticationView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
