@@ -72,6 +72,7 @@ class BatchMasterView(MasterView):
     batch_handler_class = None
     has_rows = True
     rows_deletable = True
+    rows_bulk_deletable = True
     rows_downloadable_csv = True
     rows_downloadable_xlsx = True
     refreshable = True
@@ -170,6 +171,7 @@ class BatchMasterView(MasterView):
         return self.rattail_config.batch_filepath(batch.batch_key, batch.uuid, filename)
 
     def template_kwargs_view(self, **kwargs):
+        kwargs = super(BatchMasterView, self).template_kwargs_view(**kwargs)
         use_buefy = self.get_use_buefy()
         batch = kwargs['instance']
         kwargs['batch'] = batch
@@ -417,17 +419,6 @@ class BatchMasterView(MasterView):
                 f.remove_fields('executed',
                                 'executed_by')
 
-    def make_status_renderer(self, enum):
-        def render_status(batch, field):
-            value = batch.status_code
-            if value is None:
-                return ""
-            status_code_text = enum.get(value, six.text_type(value))
-            if batch.status_text:
-                return HTML.tag('span', title=batch.status_text, c=status_code_text)
-            return status_code_text
-        return render_status
-
     def render_complete(self, batch, field):
         permission_prefix = self.get_permission_prefix()
         use_buefy = self.get_use_buefy()
@@ -880,7 +871,12 @@ class BatchMasterView(MasterView):
 
         kwargs['use_buefy'] = use_buefy
         kwargs['component'] = 'execute-form'
-        return forms.Form(schema=schema, request=self.request, defaults=defaults, **kwargs)
+        form = forms.Form(schema=schema, request=self.request, defaults=defaults, **kwargs)
+        self.configure_execute_form(form)
+        return form
+
+    def configure_execute_form(self, form):
+        pass
 
     def get_execute_title(self, batch):
         if hasattr(self.handler, 'get_execute_title'):
