@@ -110,5 +110,12 @@ class CategoryView(MasterView):
 CategoriesView = CategoryView
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    CategoryView = kwargs.get('CategoryView', base['CategoryView'])
     CategoryView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
