@@ -287,6 +287,8 @@ class CommonView(View):
 
         # permissions
         config.add_tailbone_permission_group('common', "(common)", overwrite=False)
+        config.add_tailbone_permission('common', 'common.edit_help',
+                                       "Edit help info for *any* page")
 
         # home
         config.add_route('home', '/')
