@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -80,5 +80,12 @@ class CustomerGroupView(MasterView):
 CustomerGroupsView = CustomerGroupView
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    CustomerGroupView = kwargs.get('CustomerGroupView', base['CustomerGroupView'])
     CustomerGroupView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
