@@ -1001,6 +1001,14 @@ class CustomerOrderView(MasterView):
     def _order_defaults(cls, config):
         route_prefix = cls.get_route_prefix()
         url_prefix = cls.get_url_prefix()
+        model_title = cls.get_model_title()
+        permission_prefix = cls.get_permission_prefix()
+
+        # add pseudo-index page for creating new custorder
+        # (makes it available when building menus etc.)
+        config.add_tailbone_index_page('{}.create'.format(route_prefix),
+                                       "New {}".format(model_title),
+                                       '{}.create'.format(permission_prefix))
 
         # person autocomplete
         config.add_route('{}.person_autocomplete'.format(route_prefix),
