@@ -177,5 +177,12 @@ class LabelProfileView(MasterView):
 ProfilesView = LabelProfileView
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    LabelProfileView = kwargs.get('LabelProfileView', base['LabelProfileView'])
     LabelProfileView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
