@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -201,5 +201,12 @@ class PurchaseCreditView(MasterView):
                         permission='{}.change_status'.format(permission_prefix))
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    PurchaseCreditView = kwargs.get('PurchaseCreditView', base['PurchaseCreditView'])
     PurchaseCreditView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
