@@ -461,6 +461,8 @@ class ReportOutputView(ExportMasterView):
                     value = self.request.GET[param.name]
                     if param.type is datetime.date:
                         value = app.parse_date(value)
+                    elif param.type is bool:
+                        value = self.rattail_config.parse_bool(value)
                     form.set_default(param.name, value)
 
         # if form validates, start generating new report output; show progress page
