@@ -85,6 +85,9 @@ class SubdepartmentView(MasterView):
     def configure_grid(self, g):
         super(SubdepartmentView, self).configure_grid(g)
 
+        # number
+        g.set_link('number')
+
         # name
         g.filters['name'].default_active = True
         g.filters['name'].default_verb = 'contains'
@@ -95,7 +98,6 @@ class SubdepartmentView(MasterView):
         g.set_sorter('department', model.Department.name)
         g.set_filter('department', model.Department.name)
 
-        g.set_link('number')
         g.set_link('name')
 
     def configure_form(self, f):
@@ -154,5 +156,12 @@ class SubdepartmentView(MasterView):
 SubdepartmentsView = SubdepartmentView
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    SubdepartmentView = kwargs.get('SubdepartmentView', base['SubdepartmentView'])
     SubdepartmentView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
