@@ -384,6 +384,19 @@ class TransactionView(MasterView):
             'engines_data': engines_data,
         })
 
+    def configure_get_simple_settings(self):
+        return [
+
+            # rotation
+            {'section': 'trainwreck',
+             'option': 'use_rotation',
+             'type': bool},
+            {'section': 'trainwreck',
+             'option': 'current_years',
+             'type': int},
+
+        ]
+
     def configure_get_context(self):
         context = super(TransactionView, self).configure_get_context()
 
