@@ -149,8 +149,15 @@ class UpgradeView(MasterView):
             return 'notice'
 
     def template_kwargs_view(self, **kwargs):
+        kwargs = super(UpgradeView, self).template_kwargs_view(**kwargs)
         upgrade = kwargs['instance']
 
+        kwargs['system_title'] = self.rattail_config.app_title()
+        if upgrade.system:
+            system = self.upgrade_handler.get_system(upgrade.system)
+            if system:
+                kwargs['system_title'] = system['label']
+
         kwargs['show_prev_next'] = True
         kwargs['prev_url'] = None
         kwargs['next_url'] = None
